@@ -10,14 +10,17 @@ Command Reference
 EOS
 
 while read line; do
+	line="${line//‘\\n’/\`\`\\n\`\`}"
+	line="${line//‘\\t’/\`\`\\t\`\`}"
+
 	if [[ $line =~ ^Usage:\ cpanel\ ([a-z]+)\ ([a-z]+) ]]; then
 		echo "Module: \`\`${BASH_REMATCH[2]}\`\`"
 		echo -e "==================================================\n"
 		[[ $line =~ ^Usage:\ cpanel\ (.+) ]]
-		echo -e "**${BASH_REMATCH[1]}**\n"
+		echo -e "- **${BASH_REMATCH[1]}**\n"
 
 	elif [[ $line =~ ^\ *cpanel\ (.+) ]]; then
-		echo -e "**${BASH_REMATCH[1]}**\n"
+		echo -e "- **${BASH_REMATCH[1]}**\n"
 
 	elif [[ $line =~ ^\ *EXAMPLES ]]; then
 		echo -e "*Examples*\n\n.. code:: sh\n"
@@ -25,20 +28,14 @@ while read line; do
 	elif [[ $line =~ ^\ *EXAMPLE ]]; then
 		echo -e "*Example*\n\n.. code:: sh\n"
 
-	elif [[ $line =~ ^\ *033\[1mCOMMAND ]]; then
-		echo -n ""
-
 	elif [[ $line =~ ^\ *033\[1m(.+)033\[0m ]]; then
 		echo -e "**${BASH_REMATCH[1]}**\n"
 
 	elif [[ $line =~ ^\ *033\[1\;34m(.+)033\[00m ]]; then
-		echo -e "    \$ ${BASH_REMATCH[1]}"
+		echo "    \$ ${BASH_REMATCH[1]}"
 
-	elif [[ $line =~ ^\ *033\[1\;34m(.+)033\[00m ]]; then
-		echo -e "    \$ ${BASH_REMATCH[1]}"
-
-	elif [[ $line =~ ^\ *For\ a\ complete\ User’s\ Guide ]]; then
-		echo -n ""
+	elif [[ $line =~ ^\ *033\[1\;34m(.+)032\[00m ]]; then
+		echo "    \$ ${BASH_REMATCH[1]}"
 
 	elif [[ $line =~ ^--- ]]; then
 		echo -n ""
